==> duiba-goods-center-api-0.0.1-privatization-20220708.031816-4-sources.jar: cn/com/duiba/cloud/duiba/goods/center/api/remoteservice/sale/RemoteShelfChannelService.java <==
package cn.com.duiba.cloud.duiba.goods.center.api.remoteservice.sale;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.cloud.duiba.goods.center.api.dto.sale.SkuChannelConfigDto;
import cn.com.duiba.cloud.duiba.goods.center.api.dto.sale.SpuChannelConfigDto;
import cn.com.duiba.cloud.duiba.goods.center.api.param.sale.*;
import cn.com.duiba.wolf.entity.PageResponse;

import java.util.List;

/**
 * 描述：定向渠道相关
 *
 * @author zsp (zengshuiping@duiba.com.cn)
 * @date 2022/4/2 14:02
 */
@AdvancedFeignClient
public interface RemoteShelfChannelService {

    /**
     * 修改定向分配类型（Spu 维度）
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    Boolean changeShelfTye(SpuShelfOperateParam param) throws BizException;


    /**
     * 添加定向渠道（Spu 维度）
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    Boolean addShelfChannel(SpuShelfOperateParam param) throws BizException;


    /**
     * 删除定向渠道（Spu 维度）
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    Boolean removeShelfChannel(SpuShelfOperateParam param) throws BizException;

    /**
     * 清除定向渠道配置而不删除定向渠道
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    Boolean clearShelfChannel(SpuShelfOperateParam param) throws BizException;


    /**
     * 统计渠道数量（Spu 维度）
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    Long countBySpu(ShelfChannelQueryParam param) throws BizException;

    /**
     * spu 渠道列表
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    PageResponse<SpuChannelConfigDto> pageBySpu(ShelfChannelQueryParam param) throws BizException;


    /**
     * sku 渠道列表
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    PageResponse<SkuChannelConfigDto> pageBySku(ShelfChannelQueryParam param) throws BizException;


    /**
     * 分配渠道库存（Sku 维度）
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    Boolean editSkuChannelConfig(SkuChannelConfigSaveParam param) throws BizException;


    /**
     * 根据 sku-渠道 id 获取对应的配置，如果不存在，会返回默认配置
     */
    ShelfChannelListParam listDefaultIfAbsent(ShelfChannelListParam param) throws BizException;

//
//    /**
//     * 检查商品是否在定向范围内
//     *
//     * @return
//     * @throws BizException
//     */
//    List<Long> checkConfigBySpuId(ConfigCheckParam param) throws BizException;

}

==> duiba-goods-center-api-0.0.2-privatization-20220720.061112-3-sources.jar: cn/com/duiba/cloud/duiba/goods/center/api/remoteservice/sale/RemoteShelfChannelService.java <==
package cn.com.duiba.cloud.duiba.goods.center.api.remoteservice.sale;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.cloud.duiba.goods.center.api.dto.sale.SkuChannelBatchDto;
import cn.com.duiba.cloud.duiba.goods.center.api.dto.sale.SkuChannelConfigDto;
import cn.com.duiba.cloud.duiba.goods.center.api.dto.sale.SpuChannelConfigDto;
import cn.com.duiba.cloud.duiba.goods.center.api.param.sale.*;
import cn.com.duiba.wolf.entity.PageResponse;

import java.util.List;

/**
 * 描述：定向渠道相关
 *
 * @author zsp (zengshuiping@duiba.com.cn)
 * @date 2022/4/2 14:02
 */
@AdvancedFeignClient
public interface RemoteShelfChannelService {

    /**
     * 修改定向分配类型（Spu 维度）
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    Boolean changeShelfTye(SpuShelfOperateParam param) throws BizException;


    /**
     * 添加定向渠道（Spu 维度）
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    Boolean addShelfChannel(SpuShelfOperateParam param) throws BizException;


    /**
     * 删除定向渠道（Spu 维度）
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    Boolean removeShelfChannel(SpuShelfOperateParam param) throws BizException;

    /**
     * 清除定向渠道配置而不删除定向渠道
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    Boolean clearShelfChannel(SpuShelfOperateParam param) throws BizException;


    /**
     * 清除定向渠道配置而不删除定向渠道(sku下所有的定向渠道)
     *
     * @param param
     * @return
     * @throws BizException
     */
    Boolean batchClearShelfChannel(SpuShelfClearParam param) throws BizException;


    /**
     * 批量获取sku所分配的所有渠道列表
     *
     * @param spuShelfBatchGetParam
     * @return
     */
    SkuChannelBatchDto batchGetChannel(SpuShelfBatchGetParam spuShelfBatchGetParam);


    /**
     * 统计渠道数量（Spu 维度）
     *
     * @param param
     * @return
     * @throws BizException
     */
    Long countBySpu(ShelfChannelQueryParam param) throws BizException;

    /**
     * spu 渠道列表
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    PageResponse<SpuChannelConfigDto> pageBySpu(ShelfChannelQueryParam param) throws BizException;


    /**
     * sku 渠道列表
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    PageResponse<SkuChannelConfigDto> pageBySku(ShelfChannelQueryParam param) throws BizException;


    /**
     * 分配渠道库存（Sku 维度）
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    Boolean editSkuChannelConfig(SkuChannelConfigSaveParam param) throws BizException;


    /**
     * 根据 sku-渠道 id 获取对应的配置，如果不存在，会返回默认配置
     */
    ShelfChannelListParam listDefaultIfAbsent(ShelfChannelListParam param) throws BizException;


    /**
     * 检查商品是否在定向范围内
     *
     * @return
     * @throws BizException
     */
    List<Long> checkConfigBySpuId(ConfigCheckParam param) throws BizException;

}
